==> haskell-storable-tuple-0.0.3.3-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-storable-tuple.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storable-tuple
version: 0.0.3.3
id: storable-tuple-0.0.3.3-Lc4lHBWdnS03Oqb38GodnO
key: storable-tuple-0.0.3.3-Lc4lHBWdnS03Oqb38GodnO
license: BSD3
maintainer: Henning Thielemann <storable@henning-thielemann.de>
stability: Experimental
homepage: http://code.haskell.org/~thielema/storable-tuple/
synopsis: Storable instance for pairs and triples
description:
    Provides a Storable instance for pair and triple
    which should be binary compatible with C99 and C++.
    The only purpose of this package is to provide a standard location
    for this instance so that other packages needing this instance
    can play nicely together.
category: Data, Foreign
author: Henning Thielemann <storable@henning-thielemann.de>
exposed: True
indefinite: False
exposed-modules:
    Foreign.Storable.Tuple
abi: 542ad46b022ec6258d9ce7006a808a4f
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/storable-tuple-0.0.3.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/storable-tuple-0.0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/storable-tuple-0.0.3.3
hs-libraries: HSstorable-tuple-0.0.3.3-Lc4lHBWdnS03Oqb38GodnO
depends:
    base-4.10.1.0 base-orphans-0.6-KoJqNefbvUAEuaR7CDOiu4
    storable-record-0.0.3.1-StYqDGuqEm2sD5ibCpAJt
    utility-ht-0.0.14-1SDJ0BtW7GoAaRrxZT3hIq
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-orphans-0.6-KoJqNefbvUAEuaR7CDOiu4=fb09ffe63c021a5df200f5dd3f288699
             storable-record-0.0.3.1-StYqDGuqEm2sD5ibCpAJt=7b8b41797e5d5d8867ce8a7d63f42105
             utility-ht-0.0.14-1SDJ0BtW7GoAaRrxZT3hIq=0362a121972f0b40c9fe893b813ad252
haddock-interfaces: /usr/share/doc/haskell-storable-tuple/html/storable-tuple.haddock
haddock-html: /usr/share/doc/haskell-storable-tuple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storable-tuple-0.0.3.3-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-storable-tuple.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storable-tuple
version: 0.0.3.3
id: storable-tuple-0.0.3.3-GwAbgaLwDQCIyJXoJvTGpi
key: storable-tuple-0.0.3.3-GwAbgaLwDQCIyJXoJvTGpi
license: BSD3
maintainer: Henning Thielemann <storable@henning-thielemann.de>
stability: Experimental
homepage: http://code.haskell.org/~thielema/storable-tuple/
synopsis: Storable instance for pairs and triples
description:
    Provides a Storable instance for pair and triple
    which should be binary compatible with C99 and C++.
    The only purpose of this package is to provide a standard location
    for this instance so that other packages needing this instance
    can play nicely together.
category: Data, Foreign
author: Henning Thielemann <storable@henning-thielemann.de>
exposed: True
indefinite: False
exposed-modules:
    Foreign.Storable.Tuple
abi: 02c970753a7e6b710afdf2774edd41ba
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/storable-tuple-0.0.3.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/storable-tuple-0.0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/storable-tuple-0.0.3.3
hs-libraries: HSstorable-tuple-0.0.3.3-GwAbgaLwDQCIyJXoJvTGpi
depends:
    base-4.10.1.0 base-orphans-0.6-KoJqNefbvUAEuaR7CDOiu4
    storable-record-0.0.4-6ipbCeKlvj73kYbaG0fk3X
    utility-ht-0.0.14-1SDJ0BtW7GoAaRrxZT3hIq
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-orphans-0.6-KoJqNefbvUAEuaR7CDOiu4=fb09ffe63c021a5df200f5dd3f288699
             storable-record-0.0.4-6ipbCeKlvj73kYbaG0fk3X=6c65993a5c7e1f7ab227359ee3eefaa5
             utility-ht-0.0.14-1SDJ0BtW7GoAaRrxZT3hIq=0362a121972f0b40c9fe893b813ad252
haddock-interfaces: /usr/share/doc/haskell-storable-tuple/html/storable-tuple.haddock
haddock-html: /usr/share/doc/haskell-storable-tuple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
